/**
Demo of critical bands with sine tones
David Gordon
*/

import ddf.minim.*;
import ddf.minim.ugens.*;

Minim       minim;
AudioOutput out;
Oscil       wave1, wave2;

float startFreq = 440.0;
float osc2Freq = startFreq;
float maxDist = 80;

void setup()
{
  size(512, 200, P3D);
  
  minim = new Minim(this);
  
  // use the getLineOut method of the Minim object to get an AudioOutput object
  out = minim.getLineOut();
  
  wave1  = new Oscil( startFreq, 0.1f, Waves.SINE );
  wave2  = new Oscil( startFreq, 0.1f, Waves.SINE );
  // patch the Oscil to the output
  wave1.patch( out );
  wave2.patch( out );
}

void draw()
{
  background(0);
  
  stroke(255, 255, 255);
  strokeWeight(1);
  
  // draw the waveform of the output
  for(int i = 0; i < out.bufferSize() - 1; i++)
  {
    line( i, 50  - out.left.get(i)*100,  i+1, 50  - out.left.get(i+1)*100 );
    line( i, 150 - out.right.get(i)*100, i+1, 150 - out.right.get(i+1)*100 );
  }

   text("Frequency 1:"+startFreq, 200, 190);
   text("Frequency 2:"+osc2Freq, 350, 190);
}


void mousePressed()
{
   osc2Freq = constrain( map( height-mouseY, 0, height, startFreq, startFreq+maxDist ), startFreq, startFreq+maxDist );
   wave2.setFrequency(osc2Freq);
}

void mouseDragged()
{
   osc2Freq = constrain( map( height-mouseY, 0, height, startFreq, startFreq+maxDist ), startFreq, startFreq+maxDist );
   wave2.setFrequency(osc2Freq);
}

void keyPressed()
{ 
  switch( key )
  {
    case 'r':
      wave2.setFrequency(startFreq);
      break;
     
    default: break; 
  }
}
